@@ -254,7 +254,7 @@ class Phonepatch:
 			ptt_wait_time = radioconf["ptt_wait_time"], 
 			carrier_polling = radioconf["carrier_polling_time"], \
 			fullduplex = radioconf["full_duplex"], \
-			soundcard_retries = 5)
+			soundcard_retries = 5, latency = soundcard["latency"])
 		except IOError, detail:
 			self.debug("%s" %str(detail), 1)
 			sys.exit(1)
@@ -568,18 +568,19 @@ class Phonepatch:
 		while 1:
 			if self.play(True, True, incall["report_call_audio"]) == None: break
 			answer_button = incall["answer_button"]
+			if not incall["answer_button"]: return "answered"
 			self.debug("wait %d seconds for DTMF button %s" %(incall["report_call_audio_wait"], answer_button))
-			#return 1 # temporal
+			#return "answered" # uncomment for testing
 			try: dtmf = self.detect_dtmf(answer_button, incall["report_call_audio_wait"])
 			except IOError: break
 			if dtmf:
 				self.debug("DTMF answer button received")
-				return 1
+				return "answered"
 			elif time.time() > timeout_time:
 				self.debug("incall timeout reached: %d seconds" %incall["report_call_timeout"])
 				self.play(True, True, incall["report_call_timeout_audio"])
 				break
-		return 0
+		return
 
 	###################################
 	def continue_outcall(self):
@@ -876,7 +877,7 @@ phonepatch [options]
 By default the phonepatch acts as daemon, opens radio interface 
 and spawn outgoing calls when required (radio DTMF controlled)"""
 	
-	default_template = "/usr/share/asterisk-phonepatch/phonepatch.template"
+	default_template = "/usr/share/asterisk-phonepatch/phonepatch.conf.template"
 	default_configuration = "/etc/asterisk-phonepatch/phonepatch.conf"
 	
 	optpar = optparse.OptionParser(usage)
