@@ -86,8 +86,12 @@ class Radio:
 		self.sample_width = 2
 		self.sample_max = 2.0**(2*8) / 2.0
 		
-		# Reduce soundcard fragment size (default is 4096), to reduce latency
-		self.fragment_size = 128
+		# Latency (allowe dbetween 0.01 and secs) gives the fragment size 
+		self.fragmentsize = None
+		latency = args.get("latency")
+		if latency != None: 
+			latency = min(1.0, max(0.01, latency))
+			self.fragmentsize = (samplerate * self.audio_channels * self.sample_width) * latency
 		
 		self.onoff_dict = {False: "off", True: "on"}
 		self.offtime = self.ontime = self.tailtime = 0
@@ -100,7 +104,7 @@ class Radio:
 			try: self.soundcard = soundcard.Soundcard(device = soundcard_device, \
 					channels = self.audio_channels, mode = "rw", library = "oss", \
 					samplerate = samplerate, sampleformat = self.sampleformat, \
-					fragment_size = self.fragment_size)
+					fragmentsize = self.fragmentsize)
 			except IOError, (nerror, detail): 
 				if nerror != errno.EBUSY: break
 				soundcard_retries -= 1
