@@ -105,13 +105,20 @@ class RadioControl:
 				if index >= len(device_lines): 
 					function = None
 				else:
-					try: function = lines[device_lines[index]]
+					linename = device_lines[index]
+					negate = False
+					if linename and linename[0] == "-": 
+						linename = linename[1:]
+						negate = True
+					try: function = lines[linename]
 					except: raise ValueError, "Error on device_line: %s" %device_lines[index]
 				if function: method = getattr(handler, function)
-				else: method = None
-				self.device_lines[line] = method
+				else: self.device_lines[line] = None; continue
+				if method in [x[0] for x in self.device_lines.values()]:
+					raise ValueError, "Line already used: %s" %linename
+				self.device_lines[line] = (method, negate)
 			if self.device_lines["power"]:
-				self.device_lines["power"](1)
+				self.device_lines["power"][0](1^self.device_lines["power"][1])
 
 	###################################
 	def get_ptt(self):
@@ -128,7 +135,7 @@ class RadioControl:
 			raise IOError, "RadioControl is not opened"
 		if self.mode == "serial" or self.mode == "parallel":
 			if self.device_lines["carrier"]:
-				return self.device_lines["carrier"]()
+				return self.device_lines["carrier"][0]() ^ self.device_lines["carrier"][1]
 		elif self.mode == "command":
 			self.command.write(self.command_options["get_carrier"] + "\n")
 			self.command.flush()
@@ -152,7 +159,7 @@ class RadioControl:
 		self.ptt = state
 		if self.mode == "serial" or self.mode == "parallel":
 			if self.device_lines["ptt"]:
-				self.device_lines["ptt"](state)
+				self.device_lines["ptt"][0](state ^ self.device_lines["ptt"][1])
 		elif self.mode == "command":
 			key = "set_ptt_%s" %(ONOFF[state])
 			self.command.write(self.command_options[key]  + "\n")
@@ -218,11 +225,12 @@ def get_lines_description():
 def main():
 	usage = """radio-control.py [options]
 
-Control radio PTT (output) and carrier detection (input) using a serial or 
-parallel port. Default lines (change with --device-lines):
+Control radio PTT (output) and carrier-detection (input) using a serial, 
+parallel port or an external command. Default lines are (change them
+with --device-lines):
 
-Serial port -- RTS for PTT, CTS for Carrier-Detection, DTR for power.
-Parallel port -- DATA (D0) for PTT, Busy for Carrier-Detecion, Strobe for power.
+Serial -- RTS for PTT, CTS for carrier-detection, DTR for carrier-power.
+Parallel -- D0 for PTT, Busy for carrier-detecion, Strobe for carrier-power.
 
 Available lines: 
 %s
@@ -234,14 +242,14 @@ get carrier --  Get Carrier-Detection state. Returns: "get carrier: 0|1" """ %ge
 	
 	optpar = optparse.OptionParser(usage)
 	optpar.add_option('-v', '--verbose', dest='verbose', default = False, action='store_true', help = 'Be verbose')
-	optpar.add_option('-d', '--device',  dest='device', type = "string", default = "", metavar = 'DEVICE', help = 'Device file')
 	optpar.add_option('-m', '--port-mode',  dest='mode', type = "string", default = "", metavar = 'MODE', help = 'Port mode: %s' %" | ". join(list(MODES)))
+	optpar.add_option('-d', '--device',  dest='device', type = "string", default = "", metavar = 'DEVICE', help = 'Device file')
 	optpar.add_option('-p', '--ptt',  dest='ptt', type = "string", default = "", metavar = 'STATE', help = 'Set new PTT state (on|off)')
-	optpar.add_option('-w', '--wait-time',  dest='wait', type = "float", default = None, metavar = 'SECONDS', help = 'On PTT mode, time to wait before exit')
 	optpar.add_option('-c', '--carrier-detection',  dest='carrier',  default = False, action = 'store_true', help = 'Get carrier-detection state')
+	optpar.add_option('-w', '--wait-time',  dest='wait', type = "float", default = None, metavar = 'SECONDS', help = 'On PTT mode, time to wait before exit. On Carrier detection, time before reading')
 	optpar.add_option('-s', '--server',  dest='server',  default = False, action = 'store_true', help = 'Start in server mode')
-	optpar.add_option('-o', '--command-options',  dest='command_options', type = "string", default = "", metavar = 'OPTIONS', help = 'String for command mode: ptt-on,ptt-off,get-carrier,get-carrier-response-regexp')
-	optpar.add_option('', '--device-lines',  dest='device_lines', type = "string", default = "", metavar = 'OPTIONS', help = 'String for serial/parallel mode. Give lines for PTT, CarrierDetection, Power')
+	optpar.add_option('-o', '--command-options',  dest='command_options', type = "string", default = "", metavar = 'OPTIONS', help = 'Strings for command mode: ptt-on,ptt-off,get-carrier,get-carrier-response-regexp')
+	optpar.add_option('', '--device-lines',  dest='device_lines', type = "string", default = "", metavar = 'OPTIONS', help = 'Strings for serial/parallel lines (start with "-" to negate line): ptt,get-carrier,carrier-power')
 	
 	options, args = optpar.parse_args()
 	verbose = options.verbose
@@ -277,13 +285,13 @@ get carrier --  Get Carrier-Detection state. Returns: "get carrier: 0|1" """ %ge
 	else: command_options = None
 		
 	if not options.ptt and not options.carrier and not options.server:
-		optpar.print_help()
+		optpar.print_usage()
 		sys.exit(1)
 
 	debug("options - mode: %s" %options.mode, verbose)
 	debug("options - device: %s" %options.device, verbose)
 	if device_lines: debug("options - device-lines: %s" %device_lines, verbose)
-	if options.wait: debug("options - wait time: %s" %str(options.wait), verbose)
+	if options.wait != None: debug("options - wait time: %s" %str(options.wait), verbose)
 	debug("opening device: %s" %options.device, verbose)
 	rc = RadioControl(options.mode, options.device, device_lines, command_options)
 	debug("device opened: %s" %options.device, verbose)
@@ -293,17 +301,19 @@ get carrier --  Get Carrier-Detection state. Returns: "get carrier: 0|1" """ %ge
 		rc.close(); sys.exit(0)
 
 	if options.ptt:
-		ptt = (options.ptt == "on")
-		rc.set_ptt(ptt)
+		rc.set_ptt(options.ptt == "on")
 		debug("ptt set: %s" %options.ptt, verbose)
-		if not options.wait: 
+		if options.wait == None: 
 			debug("press enter to exit")
 			raw_input()
-		elif options.wait:
-			debug("waiting %d seconds" %options.wait, verbose)
+		else:
+			debug("waiting: %d seconds" %options.wait, verbose)
 			time.sleep(options.wait)
 		
 	if options.carrier:
+		if options.wait != None:
+			debug("waiting: %d seconds" %options.wait, verbose)
+			time.sleep(options.wait)
 		try: state = rc.get_carrier()
 		except: output("error getting carrier state")
 		else: output("get carrier: %d" %int(state))
