@@ -42,10 +42,6 @@ class Soundcard:
 	Default mode is full-duplex with CD quality (mono, 8000 sps, s16_le: 16-bits 
 	signed little-endian samples)"""
 
-	#####
-	## Generic functions
-	####################################################	
-	
 	##################################################
 	def __init__(self, **args):
 		"""Open soundcard with the following args:
@@ -160,7 +156,7 @@ def main():
 	parser.add_option('-f', '--sampleformat', dest='sampleformat', default = "s16_le", metavar='AUDIO_FORMAT', type='string', help = 'sample format (u8/s8/s16_le/u16_le/s16_be/u16_be/a_law/u_law)')
 	parser.add_option('-c', '--channels', dest='channels', default = "1", metavar='NUMBER', type='int', help = 'audio channels')
 	parser.add_option('-b', '--buffersize', dest='buffersize', default = 1024, metavar = "BYTES", type = int, help = 'Buffer size for input/output')
-	parser.add_option('', '--fragment-size', dest='fragmentsize', default = "0", metavar='BYTES', type='int', help = 'Fragment size for buffers (advanced)')
+	parser.add_option('', '--fragmentsize', dest='fragmentsize', default = "0", metavar='BYTES', type='int', help = 'Fragment size for buffers (advanced)')
 
 	options, args = parser.parse_args()
 
